/*
    InkyDash

    An ESP8266 powered version of InkyCal project
    for low power desktop dashboard

    Author: tobychui


*/

/* Pin Mappings */
//Wemos D1 mini
// BUSY -> D2, RST -> D4, DC -> D3, CS -> D8, CLK -> D5, DIN -> D7, GND -> GND, 3.3V -> 3.3V

// Generic ESP8266
// BUSY -> GPIO4, RST -> GPIO2, DC -> GPIO0, CS -> GPIO15, CLK -> GPIO14, DIN -> GPIO13, GND -> GND, 3.3V -> 3.3V

/* Display Libraries */
#include <GxEPD.h>
#include <GxGDEW075Z09/GxGDEW075Z09.h>    // 7.5" b/w/r
#include <GxIO/GxIO_SPI/GxIO_SPI.h>
#include <GxIO/GxIO.h>

/* Fonts */
#include <Fonts/FreeSans9pt7b.h>
#include <Fonts/FreeSansBold9pt7b.h>
#include <Fonts/FreeSans12pt7b.h>
#include <Fonts/FreeSans18pt7b.h>
#include <Fonts/FreeSans24pt7b.h>
#include <Fonts/FreeSansBold24pt7b.h>

/* WiFi and Connections */
#include <ESP8266WiFi.h>
#include <NTPClient.h>
#include <WiFiUdp.h>
#include <WiFiManager.h>
#include <ArduinoJson.h>
#include <TaskScheduler.h>

/* WiFi and Connections */
WiFiManager wifiManager;
WiFiUDP UDPconn;
NTPClient ntpClient(UDPconn, "pool.ntp.org");

/* SPI Settings */
GxIO_Class io(SPI, /*CS=D8*/ SS, /*DC=D3*/ 0, /*RST=D4*/ 2); // arbitrary selection of D3(=0), D4(=2), selected for default of GxEPD_Class
GxEPD_Class display(io, /*RST=D4*/ 2, /*BUSY=D2*/ 4); // default selection of D4(=2), D2(=4)

/* Time Const */
const String weekDays[7] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
const String weeksDaysFull[7] = { "SUNDAY", "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY" };
const String months[12] = {"JANUARY",  "FEBRUARY",  "MARCH",  "APRIL",  "MAY",  "JUNE",  "JULY",  "AUGUST",  "SEPTEMBER",  "OCTOBER",  "NOVEMBER",  "DECEMBER"};
const String deviceName = "InkyDash v0.1";

/* Forcast */
int forcastTempMin[7] = {0,0,0,0,0,0,0};
int forcastTempMax[7] = {25,25,25,25,25,25,25};
int forcastRhMax[7] = {100,100,100,100,100,100,100};

/* Global Variables */
int currentTemp = 25;
int currentHumd = 50;
int currentRain = 0;
bool currentIsRaining = false;
bool renderForcast = true;

/* Schedulers */
/*
  void datetimeUpdateCallback();
  void todayWeatherUpdateCallback();
  void weatherForcastCallback();
  Task t_dt(10000, TASK_FOREVER, &datetimeUpdateCallback); //Date-time update task
  Task t_wt(3600000, TASK_FOREVER, &todayWeatherUpdateCallback); //Weather update task
  Task t_wf(3600000, TASK_FOREVER, &weatherForcastCallback); //Forcast update task
  Scheduler runner;
*/
void setup() {
  //Start debug serial
  Serial.begin(115200);
  Serial.println();
  Serial.println("Starting up InkyDash");
  display.init(115200);

  //Draw starting frame
  display.setRotation(3);
  display.drawPaged(drawStartingFrame);
  delay(100);

  // Connect to Wi-Fi
  wifiManager.setClass("invert");
  wifiManager.autoConnect("InkyDash Setup");

  ntpClient.begin();
  ntpClient.setTimeOffset(28800);
  
  //Draw home page
  Serial.println("WiFi Connected");
  display.drawPaged(drawHomeFrame);
}

void loop() {
  // put your main code here, to run repeatedly:

}
